FFTW 3.3.4: What FFTW Really Computes

Previous: Wisdom, Up: FFTW Reference [Contents][Index]

### 4.8 What FFTW Really Computes

In this section, we provide precise mathematical definitions for the transforms that FFTW computes. These transform definitions are fairly standard, but some authors follow slightly different conventions for the normalization of the transform (the constant factor in front) and the sign of the complex exponent. We begin by presenting the one-dimensional (1d) transform definitions, and then give the straightforward extension to multi-dimensional transforms.